@@ -7,6 +7,8 @@ from notif.channels.customerio import CustomerIO
 from notif.channels.create_group_whatsapp import CreateGroupWhatsapp
 from notif.channels.list_group_whatsapp import ListGroupWhatsapp
 from notif.channels.whatsapp_template_message_sender import WhatsappTemplateMessageSender
+from notif.channels.whatsapp_template_message_sender import WhatsappTemplateMessageSenderV3
+from notif.channels.whatsapp_custom_message_sender import WhatsappCustomMessageSender
 from notif.channels.sms_message_sender import SMSMessageSender
 
-__all__ = ['AbstractChannel', 'ProjectPushNotification', 'UserPushNotification', 'Email', 'CustomerIO', 'CreateGroupWhatsapp', 'ListGroupWhatsapp', 'WhatsappTemplateMessageSender', 'SMSMessageSender']
+__all__ = ['AbstractChannel', 'ProjectPushNotification', 'UserPushNotification', 'Email', 'CustomerIO', 'CreateGroupWhatsapp', 'ListGroupWhatsapp', 'WhatsappTemplateMessageSender', 'WhatsappCustomMessageSender', 'WhatsappTemplateMessageSenderV3', 'SMSMessageSender']
