@@ -39,3 +39,33 @@ class WhatsappTemplateMessageSender(AbstractChannel):
 
     def attachments(self):
         return []
+
+
+class WhatsappTemplateMessageSenderV3(AbstractChannel):
+
+    def __init__(self, phone_number, template_name, wa_params):
+        self.set_phone_number(phone_number)
+        self.set_template_name(template_name)
+        self.set_wa_params(wa_params)
+
+    def set_phone_number(self, phone_number):
+        self.phone_number = phone_number
+
+    def set_template_name(self, template_name):
+        self.template_name = template_name
+
+    def set_wa_params(self, wa_params):
+        self.wa_params = wa_params
+
+    def notif_type(self):
+        return 'SEND_TEMPLATE_MESSAGE_V3'
+
+    def json(self):
+        return {
+            'phone_number': self.phone_number,
+            'template_name': self.template_name,
+            'wa_params': self.wa_params,
+        }
+
+    def attachments(self):
+        return []
